@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -38,7 +38,8 @@ void ImportAddressbookJobInterfaceTest::importAddressbook()
     file->setPathConfig(zipFilePath + testPath);
     file->setExtractPath(QDir::tempPath() + testPath);
     file->setExcludePath(Utils::addressbookPath());
-    auto *impl = new ImportAddressbookJobInterfaceTestImpl(this, options, file->archiveStorage(), 1);
+    auto impl = new ImportAddressbookJobInterfaceTestImpl(
+        this, options, file->archiveStorage(), 1);
     impl->setPathConfig(file->pathConfig());
     impl->setExtractPath(file->extractPath());
     impl->setTempDirName(file->extractPath());
