@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef EXPORTAKREGATORJOBINTERFACETESTIMPL_H
-#define EXPORTAKREGATORJOBINTERFACETESTIMPL_H
+#pragma once
 
 #include "akregator/exportakregatorjobinterface.h"
 
@@ -19,4 +18,3 @@ protected:
     Q_REQUIRED_RESULT QString adaptNewResourceUrl(bool overwriteResources, const KSharedConfig::Ptr &resourceConfig, const QString &storePath) override;
     Q_REQUIRED_RESULT QString createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree) override;
 };
-#endif // EXPORTAKREGATORJOBINTERFACETESTIMPL_H
