@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef COMPAREFILEHELPER_H
-#define COMPAREFILEHELPER_H
+#pragma once
 
 #include <QString>
 
@@ -13,4 +12,3 @@ namespace CompareFileHelper {
 void compareFile(const QString &referenceFile, const QString &archiveFile);
 }
 
-#endif // COMPAREFILEHELPER_H
