@@ -4,12 +4,11 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef PIMDATAEXPORTERWINDOW_H
-#define PIMDATAEXPORTERWINDOW_H
+#pragma once
 #include <KXmlGuiWindow>
 #include "utils.h"
 class LogWidget;
-class KRecentFilesAction;
+class KRecentFilesMenu;
 class QAction;
 class QCommandLineParser;
 class PimDataBackupRestoreUI;
@@ -54,7 +53,7 @@ private:
     // Name, identifier
     QHash<QString, QString> mNeedToSyncResources;
     LogWidget *mLogWidget = nullptr;
-    KRecentFilesAction *mRecentFilesAction = nullptr;
+    KRecentFilesMenu *mRecentFilesMenu = nullptr;
     QAction *mBackupAction = nullptr;
     QAction *mRestoreAction = nullptr;
     QAction *mSaveLogAction = nullptr;
@@ -65,4 +64,3 @@ private:
     PimDataTrayIcon *mTrayIcon = nullptr;
 };
 
-#endif /* PIMDATAEXPORTERWINDOW_H */
