@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -31,7 +31,7 @@ int main(int argc, char **argv)
     if (fileName.isEmpty()) {
         return 0;
     }
-    auto *dialog = new ShowArchiveStructureDialog(fileName);
+    auto dialog = new ShowArchiveStructureDialog(fileName);
     dialog->resize(800, 600);
     dialog->show();
     app.exec();
